@@ -1,25 +1,27 @@
 # -*- coding: utf-8 -*-
 """Main Controller"""
-import os
 from tg import TGController
 from tg import expose, flash, require, url, lurl, request, redirect, validate, tmpl_context, config
 from tg.decorators import before_render, cached_property
 from tg.i18n import ugettext as _, lazy_ugettext as l_
-from repoze.what import predicates
+
+try:
+    from tg import predicates
+except ImportError:
+    from repoze.what import predicates
 
 from tgext.pluggable import app_model
 from smallpress.model import DBSession, Article, Attachment, Blog
 from smallpress.helpers import *
-from smallpress.lib.forms import UploadForm, get_article_form
+from smallpress.lib.forms import UploadForm, get_article_form, DataGrid, \
+    CSSLink, inject_datagrid_resources, SpinnerIcon
 from tgext.datahelpers.validators import SQLAEntityConverter
 from tgext.datahelpers.fields import AttachedFile
 from tgext.pluggable import plug_url, plug_redirect
 from webhelpers.html.builder import HTML
-from tw.api import CSSLink
-from tw.forms import DataGrid
-from tw.forms.validators import UnicodeString
+from formencode.validators import UnicodeString
 from datetime import datetime
-from tgext.ajaxforms.ajaxform import formexpose, spinner_icon
+from tgext.ajaxforms.ajaxform import formexpose
 from tgext.tagging.controllers import TaggingController
 from tgext.crud import EasyCrudRestController
 
@@ -103,7 +105,7 @@ class RootController(TGController):
     @require(predicates.in_group('smallpress'))
     @expose('genshi:smallpress.templates.edit')
     def new(self, blog=None, **kw):
-        attachments_table.register_resources()
+        inject_datagrid_resources(attachments_table)
 
         if 'uid' not in kw:
             if blog:
@@ -128,7 +130,7 @@ class RootController(TGController):
     @require(predicates.in_group('smallpress'))
     @expose('genshi:smallpress.templates.edit')
     def edit(self, uid, *args, **kw):
-        attachments_table.register_resources()
+        inject_datagrid_resources(attachments_table)
 
         article = DBSession.query(Article).get(uid)
         value = {
@@ -188,7 +190,7 @@ class RootController(TGController):
                     ajaxform=upload_form,
                     ajaxform_id='attachments_form',
                     ajaxform_action=upload_form.action,
-                    ajaxform_spinner=spinner_icon,
+                    ajaxform_spinner=SpinnerIcon(),
                     table=attachments_table,
                     attachments=article.attachments)
 
