@@ -98,9 +98,8 @@ class Article(DeclarativeBase):
         if whoosh_enabled:
             Article.whoosh_before_delete(mapper, connection, obj)
 
-        from smallpress.model import Tagging
-        DBSession.query(Tagging).filter(Tagging.taggable_type == 'Article')\
-                                .filter(Tagging.taggable_id == obj.uid).delete()
+        DBSession.query(app_model.Tagging).filter(app_model.Tagging.taggable_type == 'Article')\
+                                          .filter(app_model.Tagging.taggable_id == obj.uid).delete()
 
     @staticmethod
     def get_published(blog=None):
